==> haskell-hackage-security-0.6.3.2-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.3.2
visibility:           public
id:                   hackage-security-0.6.3.2-CHDf3RgkDvnA7KEagrQnJe
key:                  hackage-security-0.6.3.2-CHDf3RgkDvnA7KEagrQnJe
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  a5059910dbb2582c9abf526b49d13b83
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.3.2-CHDf3RgkDvnA7KEagrQnJe
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u
    base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-9lKR7BNsiyq7t2yDe4jjeV
    directory-1.3.7.1 ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
    filepath-1.4.2.2 ghc-prim-0.9.1 mtl-2.2.2
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-uri-2.6.4.2-DVBcu05aYxxCjTvpzOd17v parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-AZjsJHqgsjD6kJ02jOCOvu
    template-haskell-2.19.0.0 time-1.12.2 transformers-0.5.6.2
    zlib-0.7.0.0-8ZqFqGsvFQB8ur6Sh8fLj0

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-security-0.6.3.2-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.3.2
visibility:           public
id:                   hackage-security-0.6.3.2-F35zQTSvZZcGVXEf0cSNSl
key:                  hackage-security-0.6.3.2-F35zQTSvZZcGVXEf0cSNSl
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  21befd0f63e3b3de20b6b7fee48f74a7
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/hackage-security-0.6.3.2

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/hackage-security-0.6.3.2

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/hackage-security-0.6.3.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.3.2-F35zQTSvZZcGVXEf0cSNSl
depends:
    Cabal-syntax-3.10.3.0 base-4.18.3.0
    base16-bytestring-1.0.2.0-EknBegOSIL1HpdyXURsRW4
    base64-bytestring-1.2.1.0-BS9gtxrEakSHvE7f2JUUy0
    bytestring-0.11.5.4 containers-0.6.7
    cryptohash-sha256-0.11.102.1-6oFe6jjLSblHef4XZuGQge
    directory-1.3.8.5 ed25519-0.0.5.0-AYoexJ8pdTODKkH3o4jOQc
    filepath-1.4.301.0 ghc-prim-0.10.0 mtl-2.3.1
    network-3.1.4.0-BquykiICeEU8GLDFE071Z9
    network-uri-2.6.4.2-6QuJNuv1Ns4Gzjjs76diWh parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-9z7FiTSBOElC7kD8H1QNkl
    template-haskell-2.20.0.0 time-1.12.2 transformers-0.6.1.0
    zlib-0.7.0.0-DS6Da0uFkVx9bSXatFvIRX

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
